package org.jaggregator.generator;

import java.text.DateFormat;
import java.util.Collections;
import java.util.Comparator;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.TreeSet;
import org.apache.commons.collections.MultiHashMap;
import org.apache.velocity.VelocityContext;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Subscription;
import org.jaggregator.util.DateUtils;

/**
 * Groups all items of a channel/subscription by day.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class GroupByDayView 
  implements PerChannelView
{
private VelocityContext context;
private Subscription subscription;

public GroupByDayView() 
{}

public void setContext(VelocityContext context)
{
  this.context = context;
}

public void setSubscription(Subscription subscription)
{
  this.subscription = subscription;
}

public void initialize()
{
  Map dateItemMap = subscription.getDateItemMap();
  Map evenDayItemMap =
    new MultiHashMap()
    {
    public Set keySet()
    {
      Set set = new TreeSet(Collections.reverseOrder());
      set.addAll(super.keySet());
      
      return set;
    }

    public Set entrySet()
    {
      Set set = new TreeSet(
        new Comparator()
        {
        public int compare(Object o1,
                           Object o2)
        {
          Date d1 = (Date) ((Map.Entry) o1).getKey();
          Date d2 = (Date) ((Map.Entry) o2).getKey();

          return d2.compareTo(d1);
        }
        }
        );
      
      set.addAll(super.entrySet());
      
      return set;
    }
    };

  Iterator iter = dateItemMap.entrySet().iterator();
  while(iter.hasNext())
    {
      Map.Entry entry = (Map.Entry) iter.next();
      
      List itemList = (List) entry.getValue();
      Date evenDay = DateUtils.getEvenDayDateBefore((Date) entry.getKey());
      
      Iterator itemIter = itemList.iterator();
      while(itemIter.hasNext())
        evenDayItemMap.put(evenDay, (Item) itemIter.next());
    }

  context.put("dateFormat", DateFormat.getDateInstance(DateFormat.LONG));
  context.put("dateItemMap", evenDayItemMap);
}
}
