package org.jaggregator.generator;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.exception.ExceptionUtils;
import org.apache.log4j.Category;
import org.jaggregator.rss.Subscription;
import org.jaggregator.util.FileUtils;

/**
 * A HrefGenerator genrates filenames and URLs to channels etc.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.1 $
 */
public class HrefGenerator 
{
protected static final String VELOCITY_TEMPLATE_FILE_SUFFIX = ".vm";
protected static final String HTML_FILE_SUFFIX = ".html";

private Category log = Category.getInstance(HrefGenerator.class);

private File outputDirectory;
private int count = 0;

public HrefGenerator(File outputDirectory) 
{
  this.outputDirectory = outputDirectory;
}

public void setOutputDirectory(File outputDirectory)
{
  this.outputDirectory = outputDirectory;
}

private synchronized int getNextNumber()
{
  return ++count;
}

public File createFileForIndex(String templateName)
{
  String outputFileName =
    StringUtils.chompLast(templateName, 
                          VELOCITY_TEMPLATE_FILE_SUFFIX) + HTML_FILE_SUFFIX;

  File outputFile = new File(outputFileName);
  
  File ret = new File(outputDirectory, 
                      outputFile.getName());

  return ret;
}

public String createLinkToIndex(String templateName)
{
  File file = createFileForIndex(templateName);
  
  try
    {
      return file.toURL().toExternalForm();
    }
  catch(MalformedURLException ex)
    {
      log.error("can't create url for file: " + file.toString());
      log.debug(ExceptionUtils.getStackTrace(ex));
      
      return 
        templateName + "." + 
        String.valueOf(getNextNumber()) + 
        HTML_FILE_SUFFIX;
    }
}

public File createFileForSubscription(Subscription subscription)
{
  URL url = subscription.getUrl();
  
  String fileName = url.getHost() + "/" + url.getFile() + HTML_FILE_SUFFIX;
  
  fileName = fileName.replace('/', '!');
  fileName = fileName.replace('?', '!');
  
  File ret = new File(outputDirectory, 
                      fileName);
  
  return ret;
}

public String createLinkToSubscription(Subscription subscription)
{
  File file = createFileForSubscription(subscription);
  
  try
    {
      return file.toURL().toExternalForm();
    }
  catch(MalformedURLException ex)
    {
      log.error("can't create url for file: " + file.toString());
      log.debug(ExceptionUtils.getStackTrace(ex));
      
      return
        "channel." +
        String.valueOf(getNextNumber()) +
        HTML_FILE_SUFFIX;
    }
}
}
