package org.jaggregator.generator;

import java.io.File;
import java.util.Collection;
import java.util.Map;
import org.apache.velocity.VelocityContext;
import org.jaggregator.config.TemplateDecl;

/**
 * An invoker applies a template to a collection of
 * <code>SubscriptionListDecl</code> objects. How it actually
 * applies the template is dependant on the implementation. One
 * could think of several invocation methods, i.e.:
 <ul>
   <li>Apply the template once to all subscriptions in all
   subscription lists. This would create one resulting file
   consisting of data from all subscriptions in all lists.</li>

   <li>Apply the template to to each list. This would create a
   file for each list, containing data from all channels in each
   list.</li>

   <li>Apply the template to every subscription in all
   lists. This would create a file for each channel containing
   data of that channel.</li>

   <li>Apply the template to every item of every subscription in
   every list.This would create a file for each item.
 </ul>.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public interface Invoker 
{
/**
 * Set the directory to which generated files are written.
 *
 * @param directory a <code>String</code> value
 */
void setOutputDirectory(File directory);

/**
 * Apply the template <code>template</code> to
 * <code>subscriptionsCol</code>.
 *
 * @param template template
 * @param subscriptionCol <code>Collection</code> of
 * subscriptions
 * @param subscriptionListCol <code>Collection</code> containing
 * all <code>SubscriptionListDecl</code>s that we are subscribed
 * to
 * @param allSubscriptionMap <code>Map</code> of all
 * subscriptions that maps the URI of a channel to its
 * subscription
 */
void apply(TemplateDecl template,
           Collection subscriptionsCol,
           Collection subscriptionListCol,
           Map allSubscriptionsMap,
           VelocityContext context)
  throws SiteGenerationException;
}
