package org.jaggregator.generator;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Collection;
import java.util.Iterator;
import java.util.Map;
import org.apache.log4j.Category;
import org.apache.velocity.Template;
import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.Velocity;
import org.apache.velocity.exception.ParseErrorException;
import org.apache.velocity.exception.ResourceNotFoundException;
import org.jaggregator.config.TemplateDecl;
import org.jaggregator.generator.Invoker;
import org.jaggregator.generator.Invoker;
import org.jaggregator.generator.SiteGenerationException;
import org.jaggregator.rss.Subscription;

/**
 * Invoker, that invokes a template for every channel in every
 * subscription list. This invoker creates a new file for every
 * channel.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class PerChannelInvoker
  extends AbstractInvoker
{
private Category log = Category.getInstance(PerChannelInvoker.class);

public PerChannelInvoker() 
{}

public void doApply(TemplateDecl templateDecl,
                    Collection subscriptionsCol,
                    Collection subscriptionListsCol,
                    Map allSubscriptionsMap,
                    View view,
                    VelocityContext context)
  throws SiteGenerationException, ResourceNotFoundException,
  ParseErrorException, IOException, Exception
{
  String templateName = templateDecl.getFileName();

  Iterator iter = subscriptionsCol.iterator();
  
  while(iter.hasNext())
    {
      Subscription subscription = (Subscription) iter.next();
      
      log.debug("apply template: " + templateName +
                " to: " + subscription.getName());

      context.put("currentSubscription", subscription);
      
      if(view != null)
        {
          ((PerChannelView)view).setSubscription(subscription);
          view.initialize();
        }

      File outputFile = 
        hrefGenerator.createFileForSubscription(subscription);

      log.debug("write to: " + outputFile);
      
      BufferedWriter writer = writer = new BufferedWriter(
        new OutputStreamWriter(new FileOutputStream(outputFile)));
      
      Template velTemplate = 
        Velocity.getTemplate(templateName);
      velTemplate.merge(context, writer);
      
      writer.flush();
      writer.close();

      log.debug("applied template: " + templateName +
                " to: " + subscription.getName());
    }
}
}
