package org.jaggregator.generator;

import java.util.Collection;
import org.apache.velocity.VelocityContext;



/**
 * A <code>View</code> provides additional data to a velocity
 * stylesheet. It takes the collections of subscriptions to which
 * the stylesheet will be applied and and creates something
 * new. This new something is put in the velocity context. Both,
 * the view object and the stylesheet need to know the kind
 * and/or structure of data that the view will put in the
 * context.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public interface View 
{
/**
 * Initialize the view. That includes doing whatever is needed to
 * construct the view and putting it in the context.
 *
 * @param subscriptionsCol a <code>Collection</code> of subscriptions
 * @param context a <code>VelocityContext</code>
 */
void setContext(VelocityContext context);

/**
 * Initialize the view. That includes doing whatever is needed to
 * provide the stylesheet with the data it needs create the
 * view. The data will be put in the context.
 */
void initialize();
}
