package org.jaggregator.rss;

/**
 * Guid is an ID that uniquely identifies an Item. When present,
 * an aggregator may choose to use this string to determine if an
 * item is new. 
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public interface Guid 
{
/**
 * Return whether the reader may assume that it is a permalink
 * to the item, that is, a url that can be opened in a Web
 * browser, that points to the full item described by the
 * item. isPermaLink is optional, its default value is true. If
 * its value is false, the guid may not be assumed to be a url,
 * or a url to anything in particular.
 */
boolean isPermaLink();

/**
 * Set whether the reader may assume that it is a permalink
 * to the item, that is, a url that can be opened in a Web
 * browser, that points to the full item described by the
 * item. isPermaLink is optional, its default value is true. If
 * its value is false, the guid may not be assumed to be a url,
 * or a url to anything in particular.
 */
void setPermaLink(boolean permaLink);

/**
 * Get the guid string. There are no rules for the syntax of a
 * guid. Aggregators must view them as a string. It's up to the
 * source of the feed to establish the uniqueness of the string.
 */
String getGuid();

/**
 * Set the guid string. There are no rules for the syntax of a
 * guid. Aggregators must view them as a string. It's up to the
 * source of the feed to establish the uniqueness of the string.
 */
void setGuid(String guidString);
}
