package org.jaggregator.rss.common;

import java.io.IOException;
import java.util.Collection;
import java.util.Iterator;
import org.apache.commons.beanutils.ConvertUtils;
import org.apache.commons.digester.Digester;
import org.apache.commons.digester.RuleSet;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Converter;
import org.jaggregator.rss.ConverterSet;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.Rss;
import org.jaggregator.rss.RssException;
import org.jaggregator.rss.Version;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * Abstract class which helps implementing the
 * <code>Parser</code> interface.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public abstract class AbstractParser 
  extends DigesterSupport
  implements Parser
{
private Version version;

public AbstractParser(Version version)
{
  this.version = version;
}

public Channel parse(InputSource source)
  throws RssException
{
  try
    {
      Rss rss = (Rss) digester.parse(source);
      
      Channel channel = rss.getChannel();
      channel.setVersion(rss.getVersion());
  
      return channel;
    }
  catch(IOException ex)
    {
      throw new RssException(ex);
    }
  catch(SAXException ex)
    {
      throw new RssException(ex);
    }
}

public boolean canParse(Version version)
{
  return this.version.equals(version);
}
}
