package org.jaggregator.rss.common;

import java.net.URL;
import java.util.LinkedList;
import java.util.List;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.ChannelImage;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.TextInput;
import org.jaggregator.rss.Version;

/**
 * Canonical implementation of <code>Channel</code> interface.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.6 $
 */
public class ChannelImpl
  implements Channel
{
private Version version;
private String title;
private URL link;
private String description;
private ChannelImage image;
private TextInput textInput;
private List itemList;

public ChannelImpl() 
{
  this.itemList = new LinkedList();
}

public Object clone()
  throws CloneNotSupportedException
{
  return super.clone();
}

public Version getVersion() 
{
  return version;
}

public void setVersion(Version version)
{
  this.version = version;
}

public String getTitle() 
{
  return title;
}

public void setTitle(String title) 
{
  this.title = title;
}

public boolean hasTitle()
{
  return (title != null);
}

public URL getLink() 
{
  return link;
}

public void setLink(URL link)
{
  this.link = link;
}

public boolean hasLink()
{
  return (link != null);
}

public String getDescription() 
{
  return description;
}

public void setDescription(String description)
{
  this.description = description;
}

public boolean hasDescription()
{
  return (description != null);
}

public ChannelImage getImage()
{
  return image;
}

public void setImage(ChannelImage image) 
{
  this.image = image;
}

public boolean hasImage()
{
  return (image != null);
}

public TextInput getTextInput() 
{
  return textInput;
}

public void setTextInput(TextInput textInput)
{
  this.textInput = textInput;
}

public boolean hasTextInput()
{
  return (textInput != null);
}

public List getItems()
{
  return itemList;
}

public void setItems(List itemList)
{
  this.itemList = itemList;
}

public boolean addItem(Item item)
{
  return itemList.add(item);
}

public boolean hasItems()
{
  return (itemList.size() > 0);
}

public boolean channelLevelEquals(Channel o)
{
  if(this == o)
    return true;
  
  if(o == null)
    return false;

  if(this.getClass() != o.getClass())
    return false;
  
  ChannelImpl rhs = (ChannelImpl) o;
  
  return new EqualsBuilder()
    .append(version, rhs.version)
    .append(title, rhs.title)
    .append(link, rhs.link)
    .append(description, rhs.description)
    .append(image, rhs.image)
    .append(textInput, rhs.textInput)
    .isEquals();
}
}
