package org.jaggregator.rss.common;

import java.net.URL;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.apache.commons.lang.builder.HashCodeBuilder;
import org.jaggregator.rss.TextInput;
import org.jaggregator.rss.util.UrlUtils;

/**
 * Concrete Implementation of <code>TextInput</code> interface.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public class TextInputImpl 
  implements TextInput 
{
private String name;
private String title;
private URL link;
private String description;

public TextInputImpl()
{}

public String getName()
{
  return name;
}

public void setName(String name)
{
  if(name == null || name.length() == 0)
    throw new IllegalArgumentException("name == null || name.length() == 0");
  
  this.name = name;
}

public boolean hasName()
{
  return (name != null);
}

public String getTitle()
{
  return title;
}

public void setTitle(String title)
{
  if(title == null || title.length() == 0)
    throw new IllegalArgumentException("title == null || title.length() == 0");
  
  this.title = title;
}

public boolean hasTitle()
{
  return (title != null);
}

public URL getLink()
{
  return link;
}

public void setLink(URL link)
{
  if(link == null)
    throw new IllegalArgumentException("link == null");
  
  this.link = link;
}

public boolean hasLink()
{
  return (link != null);
}

public String getDescription()
{
  return description;
}

public void setDescription(String description)
{
  if(description == null || description.length() == 0)
    throw new IllegalArgumentException(
      "description == null || description.length() == 0");
  
  this.description = description;
}

public boolean hasDescription()
{
  return (description != null);
}

public boolean equals(Object o)
{
  if(this == o)
    return true;

  if(o == null)
    return false;
  
  if(this.getClass() != o.getClass())
    return false;
  
  TextInputImpl rhs = (TextInputImpl) o;
  
  return new EqualsBuilder()
    .append(name, rhs.name)
    .append(title, rhs.title)
    .append(UrlUtils.toString(link), UrlUtils.toString(rhs.link))
    .append(description, rhs.description)
    .isEquals();
}

public int hashCode()
{
  return new HashCodeBuilder(1638943, 1249)
    .append(name)
    .append(title)
    .append(UrlUtils.toString(link))
    .append(description)
    .toHashCode();
}
}
