package org.jaggregator.rss.convert;

import java.util.Date;
import java.util.Locale;
import org.apache.commons.beanutils.ConversionException;
import org.apache.commons.beanutils.locale.converters.DateLocaleConverter;
import org.jaggregator.rss.Converter;

/**
 * Converts a String into a Date.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class DateConverter 
  implements Converter 
{
//All date-times in RSS conform to the Date and Time
//Specification of RFC 822, which contains a couple of optional
//elements. Since optional elements can't be expressed in
//SimpleDateFormat's pattern language, we have to define a
//DateLocaleConverter for every possible pattern and hope that
//one of them will catch the date which is to be converted.
private DateLocaleConverter[] converters = new DateLocaleConverter[]
  {
    new DateLocaleConverter(Locale.US, 
                            "EEE, dd MMM yyyy HH:mm:ss z"),
    new DateLocaleConverter(Locale.US, 
                            "dd MMM yyyy HH:mm:ss z"),
    new DateLocaleConverter(Locale.US, 
                            "EEE, dd MMM yyyy HH:mm z"),
    new DateLocaleConverter(Locale.US, 
                            "dd MMM yyyy HH:mm z"),
  };

public Class getClazz()
{
  return Date.class;
}

public Object convert(Class clazz, Object object) 
{
  Object dateObject = null;
  
  for(int i = 0; i < converters.length; i++)
    {
      DateLocaleConverter converter = converters[i];
      
      try
        {
          dateObject = converter.convert(clazz, object);
          if(dateObject != null)
            break;
        }
      catch(ConversionException ex)
        {
        }
    }
  
  return dateObject;
}
}
