package org.jaggregator.rss.exporter;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Iterator;
import java.util.Locale;
import java.util.TimeZone;
import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.SkipDay;
import org.jaggregator.rss.rss_0_91.Channel_0_91;

/**
 * Exports <code>language, copyright, managingEditor, webMaster,
 * rating, docs, pubDate, lastBuildDate, skipDays, skipHours<code> of
 * a <code>Channel_0_91</code> object.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.10 $
 */
public class ChannelFragmentExporterImpl_0_91
  extends ChannelFragmentExporterImpl
{
private DateFormat format;

public ChannelFragmentExporterImpl_0_91()
{
  format = (DateFormat) Commons.DATE_FORMAT.clone();
  
  registerFragmentExporters();
}

protected void registerFragmentExporters()
{
  registerExporter(Channel.class, new BasicChannelFragmentExporterImpl_0_91());
}

/**
 * Does the actual export of the elements of a
 * <code>Channel_0_91</code>.
 */
private class BasicChannelFragmentExporterImpl_0_91
  implements FragmentExporter
{
public void export(Channel channel, XML channelXML, XML root, Object param)
{
  Channel_0_91 channel091 = (Channel_0_91) channel;
  
  if(channel091.hasLanguage())
    channelXML.addElement(new XML("language")
                          .addElement(channel091.getLanguage()));
  if(channel091.hasCopyright())
    channelXML.addElement(new XML("copyright")
                          .addElement(channel091.getCopyright()));
  if(channel091.hasManagingEditor())
    channelXML.addElement(new XML("managingEditor")
                          .addElement(channel091.getManagingEditor()));
  if(channel091.hasWebmaster())
    channelXML.addElement(new XML("webMaster")
                          .addElement(channel091.getWebmaster()));
  if(channel091.hasRating())
    channelXML.addElement(new XML("rating")
                          .addElement(channel091.getRating()));
  if(channel091.hasDocs())
    channelXML.addElement(new XML("docs")
                          .addElement(channel091.getDocs().toString()));

  if(channel091.hasPubDate())
    channelXML.addElement(new XML("pubDate")
                          .addElement(format.format(channel091.getPubDate())));
  if(channel091.hasLastBuildDate())
    channelXML.addElement(
      new XML("lastBuildDate")
      .addElement(format.format(channel091.getLastBuildDate())));
  if(channel091.hasSkipDays())
    {
      XML skipDaysXML = new XML("skipDays");
      Iterator iter = channel091.getSkipDays().iterator();
      while(iter.hasNext())
        {
          SkipDay skipDay = (SkipDay) iter.next();
          skipDaysXML.addElement(new XML("day").addElement(skipDay.getName()));
        }

      channelXML.addElement(skipDaysXML);
    }
  if(channel091.hasSkipHours())
    {
      XML skipHoursXML = new XML("skipHours");
      Iterator iter = channel091.getSkipHours().iterator();
      while(iter.hasNext())
        {
          Integer skipHour = (Integer) iter.next();
          skipHoursXML.addElement(new XML("hour")
                                  .addElement(skipHour.toString()));
        }
      
      channelXML.addElement(skipHoursXML);
    }
}
}
}
