package org.jaggregator.rss.exporter;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.OutputStream;
import java.io.PrintStream;
import java.io.PrintWriter;
import java.io.Writer;
import org.apache.ecs.xml.XML;
import org.apache.ecs.xml.XMLDocument;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Rss;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.util.FileUtils;

/**
 * Exporter capable of exporting a <code>Channel</code> to RSS
 * 0.91.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.15 $
 */
public class ExporterImpl_0_91 
  extends AbstractExporter
{
private PrintWriter writer;
private boolean withFile;

public ExporterImpl_0_91(File file)
  throws FileNotFoundException
{
  this(Version.VERSION_0_91, file);
}

protected ExporterImpl_0_91(Version version, File file)
  throws FileNotFoundException
{
  super(version);
  
  this.writer = new PrintWriter(FileUtils.createWriter(file));
  this.withFile = true;
  
  registerFragmentExporters();
}

public ExporterImpl_0_91(OutputStream stream)
{
  this(Version.VERSION_0_91, stream);
}

protected ExporterImpl_0_91(Version version, OutputStream ostream)
{
  super(version);

  this.writer = new PrintWriter(ostream);

  registerFragmentExporters();
}

protected void registerFragmentExporters()
{
  registerExporter(Rss.class, new RssFragmentExporterImpl_0_91());
  registerExporter(Channel.class, new ChannelFragmentExporterImpl_0_91());
  registerExporter(Channel.class, new ImageFragmentExporterImpl_0_91());
  registerExporter(Channel.class, new TextInputFragmentExporterImpl());
  registerExporter(Channel.class, new ItemFragmentExporterImpl());
}

public void export(Channel channel)
  throws IOException
{
  XMLDocument document = new XMLDocument(1.0);
  document.setCodeset("UTF-8");

  XML rssXML = new XML("rss");
  rssXML.addXMLAttribute("version", version.getName());
  document.addElement(rssXML);

  runExporters(Rss.class, channel, rssXML, rssXML, null);
  
  document.output(writer);
  writer.flush();

  if(withFile)
    writer.close();
}

/**
 * Exports everything "below" <rss>.
 */
protected class RssFragmentExporterImpl_0_91
  implements FragmentExporter
{
public void export(Channel channel, XML rssXML, XML root, Object param)
{
  XML channelXML = new XML("channel");
  rssXML.addElement(channelXML);

  runExporters(Channel.class, channel, channelXML, root, param);
}
}
}
