package org.jaggregator.rss.exporter;

import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.ChannelImage;

/**
 * Exports title, link and url of a <code>ChannelImage</code>.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class ImageFragmentExporterImpl
  extends AbstractFragmentExporter
{
public ImageFragmentExporterImpl()
{
  registerExporter(ChannelImage.class, 
                   new BasicImageFragmentExporterImpl());
}

public void export(Channel channel,
                   XML parent,
                   XML root,
                   Object param)
{
  if(channel.hasImage() == false)
    return;
  
  XML imageXML = new XML("image");
  
  runExporters(ChannelImage.class,
               channel,
               imageXML,
               root,
               null);
  
  parent.addElement(imageXML);
}

/**
 * Does the actual export of <code>title, link,
 * url</code> of a <code>ChannelImage</code>.
 */
private class BasicImageFragmentExporterImpl 
  implements FragmentExporter
{
public void export(Channel channel, XML imageXML, XML root, Object param)
{
  ChannelImage image = channel.getImage();

  if(image.hasTitle())
    imageXML.addElement(new XML("title")
                        .addElement(image.getTitle()));
  if(image.hasLink())
    imageXML.addElement(new XML("link")
                        .addElement(image.getLink().toString()));
  if(image.hasUrl())
    imageXML.addElement(new XML("url")
                        .addElement(image.getUrl().toString()));
}
}
}
