package org.jaggregator.rss.exporter;

import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Enclosure;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Source;
import org.jaggregator.rss.rss_0_92.Item_0_92;

/**
 * Exports <code>source, enclosure, category</code> of an
 * <code>Item_0_92</code>.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.7 $
 */
public class ItemFragmentExporterImpl_0_92
  extends ItemFragmentExporterImpl
{
public ItemFragmentExporterImpl_0_92()
{
  registerExporter(Item.class,
                   new SourceFragmentExporterImpl());
  registerExporter(Item.class,
                   new EnclosureFragmentExporterImpl());
  registerExporter(Item.class,
                   new CategoriesFragmentExporterImpl_0_92());
}

/**
 * Does the actual export of <code>source</code> of an
 * <code>Item_0_92</code>.
 */
private class SourceFragmentExporterImpl 
  implements FragmentExporter
{
public void export(Channel channel, XML itemXML, XML root, Object param)
{
  Item_0_92 item = (Item_0_92) param;
  
  if(item.hasSource())
    {
      Source source = item.getSource();
      
      XML sourceXML = new XML("source");
      
      if(source.hasUrl())
        sourceXML.addXMLAttribute("url",
                                  source.getUrl().toString());
      
      if(source.hasName())
        sourceXML.addElement(source.getName());
      
      itemXML.addElement(sourceXML);
    }
}
}

/**
 * Does the actual export of <code>enclosure</code> of an
 * <code>Item_0_92</code>.
 */
private class EnclosureFragmentExporterImpl 
  implements FragmentExporter
{
public void export(Channel channel, XML itemXML, XML root, Object param)
{
  Item_0_92 item = (Item_0_92) param;
  
  if(item.hasEnclosure())
    {
      Enclosure enclosure = item.getEnclosure();
      
      XML enclosureXML = new XML("enclosure");
      
      enclosureXML.addXMLAttribute("url",
                                   enclosure.getUrl().toString());
      enclosureXML.addXMLAttribute("length",
                                   String.valueOf(enclosure.getLength()));
      enclosureXML.addXMLAttribute("type",
                                   enclosure.getMimeType());
      
      itemXML.addElement(enclosureXML);
    }
}
}
}
