package org.jaggregator.rss.exporter;

import org.apache.ecs.xml.XML;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.TextInput;

/**
 * Exports <code>title, link, description, name</code> of
 * TextInput.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.8 $
 */
public class TextInputFragmentExporterImpl
  extends AbstractFragmentExporter
{
public TextInputFragmentExporterImpl()
{
  registerExporter(TextInput.class,
                   new BasicTextFragmentExporterImpl());
}

public void export(Channel channel,
                   XML parent,
                   XML root,
                   Object param)
{
  if(channel.hasTextInput() == false)
    return;
  
  XML textInputXML = new XML("textinput");

  runExporters(TextInput.class,
               channel,
               textInputXML,
               root,
               null);

  parent.addElement(textInputXML);
}

/**
 * Does the actual export of <code>title, link, description,
 * name</code> of a textinput.
 */
private class BasicTextFragmentExporterImpl 
  implements FragmentExporter
{
public void export(Channel channel, XML parent, XML root, Object param)
{
  TextInput textInput = channel.getTextInput();
  
  if(textInput.hasName())
    parent.addElement(new XML("name").addElement(textInput.getName()));
  if(textInput.hasTitle())
    parent.addElement(new XML("title")
                      .addElement(textInput.getTitle()));
  if(textInput.hasLink())
    parent.addElement(new XML("link")
                      .addElement(textInput.getLink().toString()));
  if(textInput.hasDescription())
    parent.addElement(new XML("description")
                      .addElement(textInput.getDescription()));
}
}
}
