package org.jaggregator.rss.rss_0_91;

import java.net.URL;
import java.util.Date;
import java.util.Set;
import java.util.TreeSet;
import org.apache.commons.lang.builder.EqualsBuilder;
import org.jaggregator.rss.SkipDay;
import org.jaggregator.rss.common.ChannelImpl;
import org.jaggregator.rss.Channel;

/**
 * Canonical implementation of <code>Channel_0_91</code>
 * interface.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public class ChannelImpl_0_91
  extends ChannelImpl
  implements Channel_0_91
{
private String language;
private String copyright;
private String managingEditor;
private String webmaster;
private String rating;
private URL docs;
private Date pubDate;
private Date lastBuildDate;
private Set skipDaysSet;
private Set skipHoursSet;

public ChannelImpl_0_91() 
{
  this.skipDaysSet = new TreeSet();
  this.skipHoursSet = new TreeSet();
}

public String getLanguage() 
{
  return language;
}

public void setLanguage(String language)
{
  this.language = language;
}

public boolean hasLanguage()
{
  return (language != null);
}

public String getCopyright() 
{
  return copyright;
}

public void setCopyright(String copyright)
{
  this.copyright = copyright;
}

public boolean hasCopyright()
{
  return (copyright != null);
}

public String getManagingEditor() 
{
  return managingEditor;
}

public void setManagingEditor(String managingEditor)
{
  this.managingEditor = managingEditor;
}

public boolean hasManagingEditor()
{
  return (managingEditor != null);
}

public String getWebmaster()
{
  return webmaster;
}

public void setWebmaster(String webmaster) 
{
  this.webmaster = webmaster;
}

public boolean hasWebmaster()
{
  return (webmaster != null);
}

public String getRating()
{
  return rating;
}

public void setRating(String rating)
{
  this.rating = rating;
}

public boolean hasRating()
{
  return (rating != null);
}

public URL getDocs() 
{
  return docs;
}

public void setDocs(URL docs) 
{
  this.docs = docs;
}

public boolean hasDocs()
{
  return (docs != null);
}

public Date getPubDate() 
{
  return pubDate;
}

public void setPubDate(Date pubDate) 
{
  this.pubDate = pubDate;
}

public boolean hasPubDate()
{
  return (pubDate != null);
}

public Date getLastBuildDate() 
{
  return lastBuildDate;
}

public void setLastBuildDate(Date lastBuildDate) 
{
  this.lastBuildDate = lastBuildDate;
}

public boolean hasLastBuildDate()
{
  return (lastBuildDate != null);
}

public Set getSkipDays() 
{
  return skipDaysSet;
}

public void setSkipDays(Set skipDaysSet) 
{
  this.skipDaysSet.clear();
  
  if(skipDaysSet != null)
    {
      this.skipDaysSet.addAll(skipDaysSet);
      // remove a null value if present.
      this.skipDaysSet.remove(null);
    }
}

public boolean addSkipDay(SkipDay skipDay) 
{
  if(skipDay == null)
    return false;
  
  return skipDaysSet.add(skipDay);
}

public boolean hasSkipDays()
{
  return (skipDaysSet.size() > 0);
}

public Set getSkipHours() 
{
  return skipHoursSet;
}

public void setSkipHours(Set skipHoursSet) 
{
  this.skipHoursSet.clear();
  
  if(skipHoursSet != null)
    {
      this.skipHoursSet.addAll(skipHoursSet);
      // remove a null value if present.
      this.skipHoursSet.remove(null);
    }
}

public boolean addSkipHour(int skipHour) {
  if(skipHour < 0 || skipHour > 24)
    throw new IllegalArgumentException("skipHour < 0 || skipHour > 24");

  return skipHoursSet.add(new Integer(skipHour));
}

public boolean hasSkipHours()
{
  return (skipHoursSet.size() > 0);
}

public boolean channelLevelEquals(Channel o)
{
  if(this == o)
    return true;
  
  if(o == null)
    return false;

  if(this.getClass() != o.getClass())
    return false;
  
  if(super.channelLevelEquals(o) == false)
    return false;
  
  ChannelImpl_0_91 rhs = (ChannelImpl_0_91) o;

  return new EqualsBuilder()
    .append(language, rhs.language)
    .append(copyright, rhs.copyright)
    .append(managingEditor, rhs.managingEditor)
    .append(webmaster, rhs.webmaster)
    .append(rating, rhs.rating)
    .append(docs, rhs.docs)
    .append(pubDate, rhs.pubDate)
    .append(lastBuildDate, rhs.lastBuildDate)
    .append(skipDaysSet, rhs.skipDaysSet)
    .append(skipHoursSet, rhs.skipHoursSet)
    .isEquals();
}
}
