package org.jaggregator.rss.rss_1_00;

import java.net.URL;
import org.apache.commons.digester.CallMethodRule;
import org.apache.commons.digester.CallParamRule;
import org.apache.commons.digester.Digester;
import org.apache.commons.digester.ObjectCreationFactory;
import org.apache.commons.digester.Rule;
import org.apache.commons.digester.RuleSet;
import org.xml.sax.Attributes;

import org.jaggregator.rss.common.RdfRuleSet;
import org.jaggregator.rss.digester.NamespaceCallParamRule;

/**
 * RuleSet for setting up a digester for RSS 1.0.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.5 $
 */
public class RuleSet_1_00
  implements RuleSet
{
private static final String NAMESPACE = "http://purl.org/rss/1.0/";

public RuleSet_1_00()
{}

public String getNamespaceURI()
{
  return NAMESPACE;
}

public void addRuleInstances(Digester digester)
{
  digester.addCallMethod("RDF/channel", 
                         "setAbout", 
                         1, 
                         new Class[] { String.class });
  digester.addRule("RDF/channel",
                   new NamespaceCallParamRule(
                     RdfRuleSet.NAMESPACE,
                     0,
                     "about"));
  digester.addCallMethod("RDF/channel/title", "setTitle", 0);
  digester.addCallMethod("RDF/channel/link", 
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("RDF/channel/description", "setDescription", 0);
  digester.addFactoryCreate("RDF/image", getChannelImageFactory());
  digester.addSetNext("RDF/image", "setImage");
  digester.addCallMethod("RDF/image", 
                         "setAbout", 
                         1, 
                         new Class[] { String.class });
  digester.addRule("RDF/image",
                   new NamespaceCallParamRule(
                     RdfRuleSet.NAMESPACE,
                     0,
                     "about"));
  digester.addCallMethod("RDF/image/title", "setTitle", 0);
  digester.addCallMethod("RDF/image/url", 
                         "setUrl", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("RDF/image/link", 
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addFactoryCreate("RDF/textinput", 
                            getTextInputFactory());
  digester.addCallMethod("RDF/textinput", 
                         "setAbout", 
                         1, 
                         new Class[] { String.class });
  digester.addRule("RDF/textinput",
                   new NamespaceCallParamRule(
                     RdfRuleSet.NAMESPACE,
                     0,
                     "about"));
  digester.addSetNext("RDF/textinput", "setTextInput");
  digester.addCallMethod("RDF/textinput/title", "setTitle", 0);
  digester.addCallMethod("RDF/textinput/description", 
                         "setDescription", 0);
  digester.addCallMethod("RDF/textinput/name", "setName", 0);
  digester.addCallMethod("RDF/textinput/link",
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addFactoryCreate("RDF/item", 
                            getItemFactory());
  digester.addCallMethod("RDF/item", 
                         "setAbout", 
                         1, 
                         new Class[] { String.class });
  digester.addRule("RDF/item",
                   new NamespaceCallParamRule(
                     RdfRuleSet.NAMESPACE,
                     0,
                     "about"));
  digester.addSetNext("RDF/item", "addItem");
  digester.addSetTop("RDF/item", "setChannel");
  digester.addCallMethod("RDF/item/title", "setTitle", 0);
  digester.addCallMethod("RDF/item/link", 
                         "setLink", 
                         0,
                         new Class[] { URL.class });
  digester.addCallMethod("RDF/item/description", "setDescription", 0);
}

protected ObjectCreationFactory getChannelImageFactory()
{
  return new ChannelImageFactory_1_00();
}

protected ObjectCreationFactory getTextInputFactory()
{
  return new TextInputFactory_1_00();
}

protected ObjectCreationFactory getItemFactory()
{
  return new ItemFactory_1_00();
}
}
