package org.jaggregator.rss.rss_2_00;

import java.net.URL;
import java.util.Date;
import org.apache.commons.digester.Digester;
import org.apache.commons.digester.ObjectCreationFactory;
import org.apache.commons.digester.RuleSet;
import org.jaggregator.rss.rss_0_92.RuleSet_0_92;

/**
 * RuleSet for setting up a digester for RSS 2.00.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.3 $
 */
public class RuleSet_2_00
  extends RuleSet_0_92
{
public RuleSet_2_00()
{}

/**
 * As RSS 2.00 doesn't contain namespaces per default, this
 * method returns <code>null</code>.
 */
public String getNamespaceURI()
{
  return null;
}

public void addRuleInstances(Digester digester)
{
  super.addRuleInstances(digester);

  digester.addFactoryCreate("rss/channel/category", 
                            getCategoryFactory());
  digester.addSetNext("rss/channel/category", "addCategory");
  digester.addCallMethod("rss/channel/category", 
                         "setDomain",
                         1,
                         new Class[] { String.class });
  digester.addCallParam("rss/channel/category",
                        0,
                        "domain");
  digester.addCallMethod("rss/channel/category", 
                         "setName",
                         0,
                         new Class[] { String.class });
  digester.addCallMethod("rss/channel/generator", 
                         "setGenerator",
                         0,
                         new Class[] { String.class });
  digester.addCallMethod("rss/channel/ttl", 
                         "setTtl",
                         0,
                         new Class[] { Integer.TYPE });
  digester.addCallMethod("rss/channel/item/author", 
                         "setAuthor",
                         0,
                         new Class[] { String.class });
  digester.addCallMethod("rss/channel/item/comments", 
                         "setComments",
                         0,
                         new Class[] { URL.class });
  digester.addFactoryCreate("rss/channel/item/guid", 
                            getGuidFactory());
  digester.addSetNext("rss/channel/item/guid", "setGuid");
  digester.addCallMethod("rss/channel/item/guid", 
                         "setPermaLink",
                         1,
                         new Class[] { Boolean.TYPE });
  digester.addCallParam("rss/channel/item/guid",
                        0,
                        "isPermaLink");
  digester.addCallMethod("rss/channel/item/guid", 
                         "setGuid",
                         0,
                         new Class[] { String.class });
  digester.addCallMethod("rss/channel/item/pubDate", 
                         "setPubDate",
                         0,
                         new Class[] { Date.class });
}

protected ObjectCreationFactory getChannelFactory()
{
  return new ChannelFactory_2_00();
}

protected ObjectCreationFactory getItemFactory()
{
  return new ItemFactory_2_00();
}

protected ObjectCreationFactory getGuidFactory()
{
  return new GuidFactory_2_00();
}
}
