package org.jaggregator.rss.util;

import java.net.URL;
import java.util.Date;
import java.util.HashMap;
import org.apache.log4j.Category;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.RssException;
import org.jaggregator.rss.Subscription;
import org.jaggregator.rss.util.ChannelRetriever;
import org.jaggregator.rss.util.Response;
import org.quartz.Job;
import org.quartz.JobDataMap;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;

/**
 * ChannelRetrievalJob.java
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.6 $
 */
public class ChannelRetrievalJob 
 implements Job
{
private Category log = Category.getInstance(ChannelRetrievalJob.class);

public ChannelRetrievalJob() 
{}

/**
 * Retrieves a channel.
 *
 * @param context a <code>JobExecutionContext</code> value
 * @exception JobExecutionException if an error occurs
 */
public void execute(JobExecutionContext context)
  throws JobExecutionException
{
  Thread.currentThread().yield();
  
  JobDataMap dataMap = context.getJobDetail().getJobDataMap();
  Subscription subscription = (Subscription) dataMap.get("subscription");

  log.debug("going to retrieve: " + subscription.getUrl());
  
  URL channelUri = subscription.getUrl();
  
  ChannelRetriever retriever = ChannelRetriever.getRetriever(channelUri);

  boolean useProxy = dataMap.getBoolean("useProxy");
  if(useProxy)
    {
      String proxyHost = dataMap.getString("proxyHost");
      int proxyPort = dataMap.getInt("proxyPort");
      
      retriever.setProxy(proxyHost, proxyPort);
    }

  HashMap headerMap = (HashMap) dataMap.get("headerMap");
  retriever.addHttpHeaders(headerMap);
  
  HashMap queryStringMap = (HashMap) dataMap.get("queryStringMap");
  retriever.addQueryStringParts(queryStringMap);
  
  try
    {
      Response response;
      if(subscription.hasLastModifiedString() &&
         subscription.hasEtagString())
        {
          response = retriever.retrieve(subscription.getLastModifiedString(),
                                        subscription.getEtagString());
        }
      else
        {
          response = retriever.retrieve();
        }
  
      log.debug("isRetrieveError: " + response.isRetrieveError());
      log.debug("statusCode: " + response.getStatusCode());
      
      //If response was succesfull and contained data
      if(response.isRetrieveError() == false &&
         response.getStatusCode() != 304)
        {
          Channel updatedChannel = response.getChannel();
          String lastModifiedString = response.getLastModifiedString();
          String eTagString = response.getEtagString();
      
          subscription.updateChannel(updatedChannel);
          subscription.setLastModifiedString(lastModifiedString);
          subscription.setEtagString(eTagString);

          log.debug("retrieved: " + subscription.getUrl());
        }
    }
  catch(RssException ex)
    {
      throw new JobExecutionException(ex, false);
    }
}
}
