package org.jaggregator.rss.util;

import java.io.ByteArrayInputStream;
import java.net.URL;
import java.util.Hashtable;
import java.util.Map;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.RssException;
import org.jaggregator.rss.Version;
import org.xml.sax.InputSource;

/**
 * Retrieves a channel. Retrieval is actually implemented by
 * subclasses.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.12 $
 */
public abstract class ChannelRetriever
{
private Response newResponse;
protected Hashtable headerTable;
protected Hashtable queryStringTable;
protected boolean useProxy = false;
protected String proxyHost;
protected int proxyPort;

protected ChannelRetriever()
{
  this.newResponse = new Response();
  this.headerTable = new Hashtable();
  addHttpHeader("User-Agent", "JAggregator-rsslib");

  this.queryStringTable = new Hashtable();
}

public void setProxy(String proxyHost, int proxyPort)
{
  this.useProxy = true;
  this.proxyHost = proxyHost;
  this.proxyPort = proxyPort;
}

public void addHttpHeader(String name, String value)
{
  headerTable.put(name, value);
}

public void addQueryStringPart(String name, String value)
{
  queryStringTable.put(name, value);
}

public void addHttpHeaders(Map map)
{
  headerTable.putAll(map);
}

public void addQueryStringParts(Map map)
{
  queryStringTable.putAll(map);
}

public static ChannelRetriever getRetriever(URL channelUri)
{
  ChannelRetriever retriever;
  
  if(channelUri.getProtocol().equals("file"))
    retriever = new ChannelFileRetriever(channelUri.getFile());
  else
    retriever = new ChannelHttpRetriever(channelUri);
  
  return retriever;
}

public Response retrieve()
  throws RssException
{
  byte[] channelData = retrieve(newResponse);
  
  if(channelData != null)
    {
      InputSource versionIsource = createInputSource(channelData);
      ChannelVersionDetector versionDetector = new ChannelVersionDetector();
      Version version = versionDetector.detectVersion(versionIsource);
      Parser parser = ParserFactory.getInstance().newParser(version);
      InputSource parserIsource = createInputSource(channelData);
      
      newResponse.channel = parser.parse(parserIsource);
    }
  
  return newResponse;
}

protected abstract byte[] retrieve(Response response)
  throws RetrieveException;

private InputSource createInputSource(byte[] bytes)
{
  return new InputSource(new ByteArrayInputStream(bytes));
}

public Response retrieve(String lastModifiedString, String eTagString)
  throws RssException
{
  headerTable.put("If-Modified-Since", lastModifiedString);
  headerTable.put("If-None-Match", eTagString);
  
  return retrieve();
}
}
