package org.jaggregator.rss.util;

import java.util.HashMap;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.RssException;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.rss_0_90.Parser_0_90;
import org.jaggregator.rss.rss_0_91.Parser_0_91;
import org.jaggregator.rss.rss_0_92.Parser_0_92;
import org.jaggregator.rss.rss_1_00.Parser_1_00;
import org.jaggregator.rss.rss_2_00.Parser_2_00;

/**
 * Factory for parser implementations.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class ParserFactory
{
private static ParserFactory instance;

protected ParserFactory()
{}

public Parser newParser(Version version)
  throws RssException
{
  Parser parser = null;
  
  if(version.equals(Version.VERSION_0_90))
    parser = new Parser_0_90();
  else if(version.equals(Version.VERSION_0_91))
    parser = new Parser_0_91();
  else if(version.equals(Version.VERSION_0_92))
    parser = new Parser_0_92();
  else if(version.equals(Version.VERSION_1_00))
    parser = new Parser_1_00();
  else if(version.equals(Version.VERSION_2_00))
    parser = new Parser_2_00();
  else
    throw new RssException("Unknown version: " + version.getName());
  
  return parser;
}

public static synchronized ParserFactory getInstance()
{
  if(instance == null)
    instance = new ParserFactory();
  
  return instance;
}
}
