package org.jaggregator.util;

import java.io.File;
import java.io.IOException;
import java.net.URLDecoder;
import java.net.URLEncoder;


/**
 * Utility functions for files.
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class FileUtils 
{
public static String uriToFileName(String uri)
{
  return URLEncoder.encode(uri);
}

public static String fileNameToUri(String fileName)
{
  return URLDecoder.decode(fileName);
}

public static boolean isFileReadable(File file)
{
  return 
    file.exists() &&
    file.isFile() &&
    file.canRead();
}

public static boolean isFileWritable(File file)
{
  return 
    file.exists() &&
    file.isFile() &&
    file.canWrite();
}

/**
 * Set up a directory. If <code>directory</code> does not exist
 * it tries to mkdir it.
 *
 * @param directory a <code>File</code> value
 *
 * @exception IOException if <code>directory</code> already
 * exists and is a file or if permissions don't allow to mkdir
 * it.
 */
public static void setupDirectory(File directory)
  throws IOException
{
  if(directory.exists() && directory.isFile())
    throw new IOException(directory + " is not a directory.");
  else if(directory.exists() == false)
    {
      boolean success = directory.mkdir();
      
      if(!success)
        throw new IOException("Can't create directory " + directory);
    }
}
}
