package org.jaggregator.util;

import java.io.StringReader;
import java.io.StringWriter;
import org.apache.commons.collections.Predicate;
import org.apache.commons.digester.CallMethodRule;
import org.apache.log4j.Category;
import org.apache.xerces.xni.XMLString;
import org.apache.xerces.xni.parser.XMLDocumentFilter;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.cyberneko.html.HTMLConfiguration;
import org.cyberneko.html.filters.Writer;

/**
 * Utilityclass that cleans HTML. Insecure HTML fragments such as javascripts
 * are removed.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.1 $
 */
public class HtmlFilter
{
private static Category log =
  Category.getInstance(HtmlFilter.class);

public static String filter(String text)
  throws Exception
{
  log.debug("filter -- begin");

  log.debug(text);

  SecureHtmlFilter secureHtmlFilter = new SecureHtmlFilter();
  BlankTargetHtmlEnhancer enhancer = new BlankTargetHtmlEnhancer();
  StringWriter sanitizedHtmlWriter = new StringWriter(text.length());
  Writer writer = new InMemoryHtmlWriter(sanitizedHtmlWriter, "UTF-8");

  XMLDocumentFilter[] filters =
    {
      secureHtmlFilter,
      enhancer,
      writer
    };

  XMLParserConfiguration htmlParser = new HTMLConfiguration();
  htmlParser.setProperty("http://cyberneko.org/html/properties/filters",
                         filters);
  htmlParser.setProperty("http://cyberneko.org/html/properties/names/elems",
                         "match");

  StringReader reader = new StringReader(text);

  XMLInputSource source = new XMLInputSource(null,
                                             null,
                                             null,
                                             reader,
                                             "UTF-8");
  htmlParser.parse(source);
  String sanitizedHtml = sanitizedHtmlWriter.toString();
  log.debug("nach parser: " + sanitizedHtml);
  log.debug("sanitizeHtml -- end");

  return sanitizedHtml;
}

public static String createAHrefStartTag(String href)
{
  return "<a href=\"" + filterHref(href) + "\" target=\"_blank\">";
}

public static String createPlainAHrefStartTag(String href)
{
  return "<a href=\"" + filterHref(href) + "\">";
}

public static String filterHref(String href)
{
  String javascript = "javascript:";
  String trimmedHref = href.trim();
  int index = trimmedHref.indexOf(javascript);
  String filteredHref = href;
  if(index >= 0)
    filteredHref = trimmedHref.substring(index + javascript.length(),
                                         trimmedHref.length());

  return filteredHref;
}
}

