package org.jaggregator.rss.rss_0_90;

import java.net.URL;
import java.util.Date;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Category;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.ChannelImage;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.TextInput;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.common.ItemImpl;
import org.xml.sax.InputSource;

/**
 * Unit Test for class Parser_0_90.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class TestParser_0_90 
  extends TestCase 
{
private static final Category log;
private Channel channel;

static
{
  BasicConfigurator.configure();
  log = Category.getInstance(TestParser_0_90.class);
}

public TestParser_0_90 (String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  Parser parser = new Parser_0_90();
  
  channel = parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_90/rss-example-0.90.xml"));
}

public void testParse()
{
  assertNotNull(channel);
}

public void testVersion()
{
  Version actualValue = channel.getVersion();
  Version expectedValue = Version.VERSION_0_90;
  assertEquals(expectedValue, actualValue);
}

public void testTitle()
{
  String actualValue = channel.getTitle();
  String expectedValue = "freshmeat.net";
  
  assertEquals(expectedValue, actualValue);
}

public void testLink()
  throws Exception
{
  URL actualLink = channel.getLink();
  URL expectedLink = new URL("http://freshmeat.net/");
  
  assertEquals(expectedLink, actualLink);
}

public void testDescription()
{
  String actualValue = channel.getDescription();
  String expectedValue = "freshmeat.net maintains the Web's largest index of Unix and cross-platform open source software. Thousands of applications are meticulously cataloged in the freshmeat.net database, and links to new code are added daily.";
  
  assertEquals(expectedValue, actualValue);
}

public void testImage()
{
  ChannelImage actualValue = channel.getImage();
  
  assertNotNull(actualValue);
}

public void testImageTitle()
{
  String actualValue = channel.getImage().getTitle();
  String expectedValue = "freshmeat.net";
  
  assertEquals(expectedValue, actualValue);
}

public void testImageUrl()
  throws Exception
{
  URL actualValue = channel.getImage().getUrl();
  URL expectedValue = new URL("http://images.freshmeat.net/button.gif");
  
  assertEquals(expectedValue, actualValue);
}

public void testImageLink()
  throws Exception
{
  URL actualValue = channel.getImage().getLink();
  URL expectedValue = new URL("http://freshmeat.net/");
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInput()
{
  TextInput actualValue = channel.getTextInput();
  
  assertNotNull(actualValue);
}

public void testTextInputTitle()
{
  String actualValue = channel.getTextInput().getTitle();
  String expectedValue = "Search freshmeat.net";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputLink()
  throws Exception
{
  URL actualValue = channel.getTextInput().getLink();
  URL expectedValue = new URL("http://freshmeat.net/search/");
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputDescription()
{
  String actualValue = channel.getTextInput().getDescription();
  String expectedValue = "Search freshmeat.net projects";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputName()
{
  String actualValue = channel.getTextInput().getName();
  String expectedValue = "q";
  
  assertEquals(expectedValue, actualValue);
}

public void testItems()
{
  List actualValue = channel.getItems();
  
  assertNotNull(actualValue);
  assertEquals(2, actualValue.size());
}

public void testItemChannelRelationship()
{
  Item item = (Item) channel.getItems().get(0);
  Channel actualValue = item.getChannel();
  Channel expectedValue = channel;
  
  assertEquals(expectedValue, actualValue);
}

public void testItemsContent()
  throws Exception
{
  List actualValue = channel.getItems();
  List expectedValue = new LinkedList();
  expectedValue.add(
    new ItemImpl("Jess 6.1b2 (Development)", 
                 new URL("http://freshmeat.net/releases/113010/"),
                 null));
  expectedValue.add(
    new ItemImpl("JZlib 1.0.0", 
                 new URL("http://freshmeat.net/releases/113007/"),
                 null));
  
  assertEquals(expectedValue, actualValue);
}
}
