package org.jaggregator.rss.rss_0_91;

import java.net.URL;
import java.util.Date;
import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;
import org.apache.log4j.BasicConfigurator;
import org.apache.log4j.Category;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.ChannelImage;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.SkipDay;
import org.jaggregator.rss.TextInput;
import org.jaggregator.rss.Version;
import org.jaggregator.rss.common.ItemImpl;
import org.xml.sax.InputSource;

/**
 * Unit Test for class Parser_0_91.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version
 */
public class TestParser_0_91 
  extends TestCase 
{
private static final Category log;
private Channel_0_91 channel;

static
{
  BasicConfigurator.configure();
  log = Category.getInstance(TestParser_0_91.class);
}

public TestParser_0_91 (String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  Parser parser = new Parser_0_91();
  
  channel = (Channel_0_91) parser.parse(
   createInputSourceForFile(
      "src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.2.xml"));
}

public void testParse()
{
  assertNotNull(channel);
}

public void testVersion()
{
  Version actualValue = channel.getVersion();
  Version expectedValue = Version.VERSION_0_91;
  assertEquals(expectedValue, actualValue);
}

public void testTitle()
{
  String actualValue = channel.getTitle();
  String expectedValue = "Title";
  
  assertEquals(expectedValue, actualValue);
}

public void testLink()
  throws Exception
{
  URL actualLink = channel.getLink();
  URL expectedLink = new URL("http://www.janek.org");
  
  assertEquals(expectedLink, actualLink);
}

public void testDescription()
{
  String actualValue = channel.getDescription();
  String expectedValue = "Description";
  
  assertEquals(expectedValue, actualValue);
}

public void testLanguage()
{
  String actualValue = channel.getLanguage();
  String expectedValue = "de-de";
  
  assertEquals(expectedValue, actualValue);
}

public void testCopyright()
{
  String actualValue = channel.getCopyright();
  String expectedValue = "Copyright";
  
  assertEquals(expectedValue, actualValue);
}

public void testManagingEditor()
{
  String actualValue = channel.getManagingEditor();
  String expectedValue = "managingEditor";
  
  assertEquals(expectedValue, actualValue);
}

public void testWebmaster()
{
  String actualValue = channel.getWebmaster();
  String expectedValue = "webmaster";
  
  assertEquals(expectedValue, actualValue);
}

public void testRating()
{
  String actualValue = channel.getRating();
  String expectedValue = "Rating";
  
  assertEquals(expectedValue, actualValue);
}

public void testImage()
{
  ChannelImage actualValue = channel.getImage();
  
  assertNotNull(actualValue);
}

public void testImageTitle()
{
  String actualValue = channel.getImage().getTitle();
  String expectedValue = "Imagetitle";
  
  assertEquals(expectedValue, actualValue);
}

public void testImageUrl()
  throws Exception
{
  URL actualValue = channel.getImage().getUrl();
  URL expectedValue = new URL("http://janek.org/image");
  
  assertEquals(expectedValue, actualValue);
}

public void testImageLink()
  throws Exception
{
  URL actualValue = channel.getImage().getLink();
  URL expectedValue = new URL("http://janek.org");
  
  assertEquals(expectedValue, actualValue);
}

public void testImageWidth()
  throws Exception
{
  int actualValue = ((ChannelImage_0_91)channel.getImage()).getWidth();
  int expectedValue = 88;
  
  assertEquals(expectedValue, actualValue);
}

public void testImageHeight()
  throws Exception
{
  int actualValue = ((ChannelImage_0_91)channel.getImage()).getHeight();
  int expectedValue = 31;
  
  assertEquals(expectedValue, actualValue);
}

public void testImageDescription()
  throws Exception
{
  String actualValue = 
    ((ChannelImage_0_91)channel.getImage()).getDescription();
  String expectedValue = "Imagedescription";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInput()
{
  TextInput actualValue = channel.getTextInput();
  
  assertNotNull(actualValue);
}

public void testTextInputTitle()
{
  String actualValue = channel.getTextInput().getTitle();
  String expectedValue = "TextInputTitle";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputLink()
  throws Exception
{
  URL actualValue = channel.getTextInput().getLink();
  URL expectedValue = new URL("http://janek.org/textinput");
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputDescription()
{
  String actualValue = channel.getTextInput().getDescription();
  String expectedValue = "TextInputDescription";
  
  assertEquals(expectedValue, actualValue);
}

public void testTextInputName()
{
  String actualValue = channel.getTextInput().getName();
  String expectedValue = "TextInputName";
  
  assertEquals(expectedValue, actualValue);
}

public void testDocs()
  throws Exception
{
  URL actualValue = channel.getDocs();
  URL expectedValue = new URL("http://backend.userland.com/rss");
  
  assertEquals(expectedValue, actualValue);
}

public void testPubDate()
  throws Exception
{
  Date actualValue = channel.getPubDate();
  Date expectedValue = new Date(1040673600000L);
  
  assertEquals(expectedValue, actualValue);
}

public void testBuildDate()
  throws Exception
{
  Date actualValue = channel.getLastBuildDate();
  Date expectedValue = new Date(1040760000000L);
  
  assertEquals(expectedValue, actualValue);
}

public void testSkipDays()
{
  Set actualValue = channel.getSkipDays();
  Set expectedValue = new HashSet();
  expectedValue.add(SkipDay.MONDAY);
  expectedValue.add(SkipDay.SUNDAY);
  
  assertEquals(expectedValue, actualValue);
}

public void testSkipHours()
{
  Set actualValue = channel.getSkipHours();
  Set expectedValue = new HashSet();
  expectedValue.add(new Integer(0));
  expectedValue.add(new Integer(1));
  expectedValue.add(new Integer(2));
  expectedValue.add(new Integer(3));
  expectedValue.add(new Integer(4));
  expectedValue.add(new Integer(21));
  expectedValue.add(new Integer(22));
  expectedValue.add(new Integer(23));

  assertEquals(expectedValue, actualValue);
}

public void testItems()
  throws Exception
{
  List actualValue = channel.getItems();
  List expectedValue = new LinkedList();

  ItemImpl expectedValue1 = new ItemImpl("Itemtitle1", 
                                 new URL("http://janek.org/item1"),
                                         "Description1");
  ItemImpl expectedValue2 = new ItemImpl("Itemtitle2", 
                                 new URL("http://janek.org/item2"),
                                         "Description2");
  ItemImpl expectedValue3 = new ItemImpl("Itemtitle3", 
                                 new URL("http://janek.org/item3"),
                                         "Description3");
  ItemImpl expectedValue4 = new ItemImpl("Entities: & ' < > \"", 
                                 new URL("http://janek.org/item4"),
                                         "Description4");
  
  expectedValue.add(expectedValue1);
  expectedValue.add(expectedValue2);
  expectedValue.add(expectedValue3);
  expectedValue.add(expectedValue4);

  assertEquals(expectedValue, actualValue);
}

public void testItemChannelRelationship()
{
  Item item = (Item) channel.getItems().get(0);
  Channel actualValue = item.getChannel();
  Channel expectedValue = channel;
  
  assertEquals(expectedValue, actualValue);
}
}
