package org.jaggregator.rss.util;

import java.io.File;
import java.net.URL;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Channel;

/**
 * Unit Test for class TestChannelFileRetriever.java
 *
 * @author <a href="mailto:jsz@jaggregator.org">Janek Schwarz</a>
 * @version $Revision: 1.2 $
 */
public class TestChannelFileRetriever
  extends TestCase
{
private Response firstResponse;

public TestChannelFileRetriever (String name)
{
  super(name);
}

public void testRetrieveLocalChannel091()
  throws Exception
{
  File localChannelFile = 
    createFile("src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml");
  
  URL channelUrl = localChannelFile.toURL();
  
  ChannelRetriever retriever = ChannelRetriever.getRetriever(channelUrl);
  Response response = retriever.retrieve();
  Channel retrievedChannel = response.getChannel();
  
  assertNotNull(retrievedChannel);
  
  String actualValue = retrievedChannel.getTitle();
  String expectedValue = "WriteTheWeb";
  
  assertEquals(expectedValue, actualValue);

  firstResponse = response;
}


public void testRetrieveIfModifiedSince()
  throws Exception
{
  testRetrieveLocalChannel091();
  
  File localChannelFile = 
    createFile("src/test/org/jaggregator/rss/rss_0_91/rss-example-0.91.xml");
  
  URL channelUri = localChannelFile.toURL();
   ChannelRetriever retriever = 
     ChannelRetriever.getRetriever(channelUri);
   
  Response response = retriever.retrieve(firstResponse.getLastModifiedString(),
                                         firstResponse.getEtagString());

  Channel retrievedChannel = response.getChannel();
  
  assertFalse(response.isRetrieveError());
  assertEquals(304, response.getStatusCode());
  assertNull(response.getChannel());
}
}
