package org.jaggregator.rss.util;

import java.io.File;
import java.net.URL;
import java.util.List;
import org.jaggregator.TestCase;
import org.jaggregator.rss.Subscription;

/**
 * Unit Test for unsubscribing from a
 * <code>SubscriptionRegistry</code>.
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.3 $
 */
public class TestUnsubscribeFromRegistry
  extends TestCase
{
private File subscriptionsRootFrom = 
  createFile("src/test/org/jaggregator/rss/common/subscriptionsroot");

private File subscriptionsRoot = createFile("target/subscriptionsRoot");
private File subscriptionDirectory;
private SubscriptionRegistry registry;
private URL channelUri;

public TestUnsubscribeFromRegistry(String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  channelUri = new URL(
    "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml");

  subscriptionsRoot.mkdir();
  
  String subscriptionDirectoryName = 
    FileUtils.uriToFileName(channelUri.toString());
  subscriptionDirectory = new File(subscriptionsRoot,
                                   subscriptionDirectoryName);
  subscriptionDirectory.mkdir();
  File subscriptionDirectoryFrom = new File(subscriptionsRootFrom,
                                            subscriptionDirectoryName);
  
  File subscriptionXmlFile = new File(subscriptionDirectoryFrom,
                                      "subscription.xml");
  FileUtils.copyFileToDirectory(subscriptionXmlFile,
                                subscriptionDirectory);
  File channelXmlFile = new File(subscriptionDirectoryFrom,
                                 "channel.xml");
  FileUtils.copyFileToDirectory(channelXmlFile,
                                subscriptionDirectory);

  registry =
    SubscriptionRegistry.getInstance(subscriptionsRoot);

  registry.initialize();
}

protected void tearDown()
  throws Exception
{
  List exceptionList = SubscriptionRegistry.shutdown(registry, false);

  if(exceptionList.size() > 0)
    fail("exceptions in tearDown: "+ exceptionList);

  FileUtils.deleteDirectory(subscriptionsRoot);
}

public void testUnsubscribe()
  throws Exception
{
  Subscription s = 
    (Subscription) registry.getSubscription(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml"));

  assertEquals(
    s,
    registry.unsubscribe(
      new URL(
        "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml")));
}

public void testUnsubscribeFromScheduler()
  throws Exception
{
  registry.scheduleRetrieval();

  Subscription s = registry.unsubscribe(
    new URL(
      "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml"));

  String groupName = registry.getGroupName();
  String jobName = registry.createJobName(s);
  
  String[] jobNames = registry.scheduler.getJobNames(groupName);
  
  for(int i = 0; i < jobNames.length; i++)
    {
      if(jobNames[i].equals(jobName))
        fail("job: " + jobName + " still scheduled");
    }
}

public void testUnsubscribeFromDisk()
  throws Exception
{
  registry.scheduleRetrieval();

  Subscription s = registry.unsubscribe(
    new URL(
      "http://www.jaggregator.org/testbed/subscriptiontestchannel.xml"));

  assertFalse(subscriptionDirectory.exists());
}
}
