package org.jaggregator.util;

import java.io.StringReader;
import java.io.StringWriter;
import junit.framework.TestCase;
import org.apache.xerces.xni.parser.XMLDocumentFilter;
import org.apache.xerces.xni.parser.XMLInputSource;
import org.apache.xerces.xni.parser.XMLParserConfiguration;
import org.cyberneko.html.HTMLConfiguration;
import org.cyberneko.html.filters.Writer;

/**
 * Testcase for BlankTargetHtmlEnhancer
 *
 * @author Janek Schwarz <jsz@jaggregator.org>
 * @version $Revision: 1.1 $
 */
public class TestBlankTargetHtmlEnhancer
  extends TestCase
{
private XMLParserConfiguration htmlParser;
private StringWriter htmlOutputBuffer;

protected void setUp()
{
  BlankTargetHtmlEnhancer enhancer =
    new BlankTargetHtmlEnhancer();
  htmlOutputBuffer = new StringWriter();
  Writer writer = new InMemoryHtmlWriter(htmlOutputBuffer, "UTF-8");

  XMLDocumentFilter[] filters =
    {
      enhancer,
      writer
    };

  htmlParser = new HTMLConfiguration();
  htmlParser.setProperty("http://cyberneko.org/html/properties/filters",
                         filters);
  htmlParser.setProperty("http://cyberneko.org/html/properties/names/elems",
                         "match");
}

public void testAhref()
  throws Exception
{
  StringReader reader = new StringReader(
    "<html><body><a href=\"http://www.janek.org\">janek.org</a></body></html>");

  XMLInputSource source = new XMLInputSource(null,
                                             null,
                                             null,
                                             reader,
                                             "UTF-8");
  htmlParser.parse(source);
  String actualValue = htmlOutputBuffer.toString();
  String expectedValue =
    "<html><body><a href=\"http://www.janek.org\" target=\"_blank\">" +
    "janek.org</a></body></html>";

  assertEquals(expectedValue, actualValue);
}

public void testAname()
  throws Exception
{
  StringReader reader = new StringReader(
    "<html><body><a name=\"anchorName\"></a></body></html>");

  XMLInputSource source = new XMLInputSource(null,
                                             null,
                                             null,
                                             reader,
                                             "UTF-8");
  htmlParser.parse(source);
  String actualValue = htmlOutputBuffer.toString();
  String expectedValue =
    "<html><body><a name=\"anchorName\"></a></body></html>";

  System.err.println("actualValue: " + actualValue);

  assertEquals(expectedValue, actualValue);
}
}

