package org.jaggregator.util;

import org.jaggregator.TestCase;
import org.jaggregator.rss.Channel;
import org.jaggregator.rss.Item;
import org.jaggregator.rss.Parser;
import org.jaggregator.rss.rss_0_92.Parser_0_92;
import org.xml.sax.InputSource;

/**
 * Unit Test for class ItemImpl.java
 *
 * @author <a href="mailto:jsz@jaggregator.de">Janek Schwarz</a>
 * @version $Revision: 1.1 $
 */
public class TestHtmlFilter
  extends TestCase
{
private Channel channel;

public TestHtmlFilter(String name)
{
  super(name);
}

protected void setUp()
  throws Exception
{
  Parser parser = new Parser_0_92();
  channel = parser.parse(
    createInputSourceForFile(
      "src/test/org/jaggregator/util/testhtmlfilter.xml"));
}

public void testEmbedInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(0);

  String expectedValue = "desc:embed-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testEmbedInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(0);

  String expectedValue = "title:embed-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testObjectInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(1);

  String expectedValue = "desc:object-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testObjectInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(1);

  String expectedValue = "title:object-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testMetaInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(2);

  String expectedValue = "desc:meta-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testMetaInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(2);

  String expectedValue = "title:meta-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testFramesetInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(3);

  String expectedValue = "desc:frameset-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testFramesetInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(3);

  String expectedValue = "title:frameset-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testFrameInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(4);

  String expectedValue = "desc:frame-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testFrameInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(4);

  String expectedValue = "title:frame-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testIframeInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(5);

  String expectedValue = "desc:iframe-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testIframeInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(5);

  String expectedValue = "title:iframe-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testLinkInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(6);

  String expectedValue = "desc:link-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testLinkInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(6);

  String expectedValue = "title:link-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testStyleInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(7);

  String expectedValue = "desc:style-test.";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testStyleInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(7);

  String expectedValue = "title:style-test.";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testStyleAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(8);

  String expectedValue = "desc:style-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testStyleAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(8);

  String expectedValue = "title:style-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnAbortAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(9);

  String expectedValue = "desc:onAbort-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnAbortAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(9);

  String expectedValue = "title:onAbort-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnBlurAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(10);

  String expectedValue = "desc:onBlur-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnBlurAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(10);

  String expectedValue = "title:onBlur-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnChangeAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(11);

  String expectedValue = "desc:onChange-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnChangeAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(11);

  String expectedValue = "title:onChange-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnClickAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(12);

  String expectedValue = "desc:onClick-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnClickAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(12);

  String expectedValue = "title:onClick-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnDblclickAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(13);

  String expectedValue = "desc:onDblclick-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnDblclickAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(13);

  String expectedValue = "title:onDblclick-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnErrorAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(14);

  String expectedValue = "desc:onError-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnErrorAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(14);

  String expectedValue = "title:onError-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnFocusAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(15);

  String expectedValue = "desc:onFocus-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnFocusAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(15);

  String expectedValue = "title:onFocus-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnKeydownAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(16);

  String expectedValue = "desc:onKeydown-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnKeydownAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(16);

  String expectedValue = "title:onKeydown-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnKeypressAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(17);

  String expectedValue = "desc:onKeypress-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnKeypressAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(17);

  String expectedValue = "title:onKeypress-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnKeyupAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(18);

  String expectedValue = "desc:onKeyup-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnKeyupAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(18);

  String expectedValue = "title:onKeyup-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnLoadAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(19);

  String expectedValue = "desc:onLoad-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnLoadAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(19);

  String expectedValue = "title:onLoad-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnMousedownAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(20);

  String expectedValue = "desc:onMousedown-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnMousedownAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(20);

  String expectedValue = "title:onMousedown-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnMousemoveAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(21);

  String expectedValue = "desc:onMousemove-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnMousemoveAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(21);

  String expectedValue = "title:onMousemove-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnMouseoutAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(22);

  String expectedValue = "desc:onMouseout-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnMouseoutAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(22);

  String expectedValue = "title:onMouseout-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnMouseoverAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(23);

  String expectedValue = "desc:onMouseover-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnMouseoverAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(23);

  String expectedValue = "title:onMouseover-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnMouseupAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(24);

  String expectedValue = "desc:onMouseup-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnMouseupAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(24);

  String expectedValue = "title:onMouseup-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnResetAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(25);

  String expectedValue = "desc:onReset-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnResetAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(25);

  String expectedValue = "title:onReset-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnSelectAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(26);

  String expectedValue = "desc:onSelect-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnSelectAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(26);

  String expectedValue = "title:onSelect-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnSubmitAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(27);

  String expectedValue = "desc:onSubmit-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnSubmitAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(27);

  String expectedValue = "title:onSubmit-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testOnUnloadAttrInItemDescription()
  throws Exception
{
  Item item = (Item) channel.getItems().get(28);

  String expectedValue = "desc:onUnload-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getDescription());

  assertEquals(expectedValue, actualValue);
}

public void testOnUnloadAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(28);

  String expectedValue = "title:onUnload-attr-test.<p></p>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testHrefJavascriptAttrInItemTitle()
  throws Exception
{
  Item item = (Item) channel.getItems().get(29);

  String expectedValue = "title:href-attr-test.<a></a>";
  String actualValue = HtmlFilter.filter(item.getTitle());

  assertEquals(expectedValue, actualValue);
}

public void testCreateAHref()
{
  String expectedValue = "<a href=\"index.html\" target=\"_blank\">";
  String actualValue = HtmlFilter.createAHrefStartTag("index.html");

  assertEquals(expectedValue, actualValue);
}

public void testCreateAHref2()
{
  String expectedValue = "<a href=\"index.html\" target=\"_blank\">";
  String actualValue = HtmlFilter.createAHrefStartTag("javascript:index.html");

  assertEquals(expectedValue, actualValue);
}

public void testCreateAHref3()
{
  String expectedValue = "<a href=\"index.html\" target=\"_blank\">";
  String actualValue = HtmlFilter.createAHrefStartTag(
    "  javascript:index.html");

  assertEquals(expectedValue, actualValue);
}
}
